@@ -17,7 +17,7 @@ a winamp/xmms type feature-rich audio player written in Qt
 all
 </installable>
 
-<screenshot>none</screenshot>
+<screenshot>https://screenshots.debian.net/screenshots/000/011/984/large.png</screenshot>
 
 <preinstall>
 
